==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Keng Tounspur',
	'aucun_document' => 'Keen Dokument',
	'aucun_file' => 'Kee Dokument',
	'aucun_image' => 'Kee Bild',
	'aucun_video' => 'Kéng Sequenz',
	'aucune_utilisation' => 'Dëst Dokument gëtt net benotzt',
	'aucune_vignette' => 'Keng Vignette',

	// B
	'bouton_ajouter_document' => 'Dokument derbäi setzen',
	'bouton_ajouter_image' => 'Bild derbäi setzen',
	'bouton_ajouter_image_document' => 'E Bild oder en Dokument derbäi setzen',
	'bouton_attacher_document' => 'Unhänken',
	'bouton_copier_local' => 'Op de Site kopéieren',
	'bouton_download_depuis' => 'zënter:',
	'bouton_download_local' => 'mäi Computer',
	'bouton_download_par_ftp' => 'de Server',
	'bouton_download_par_mediatheque' => 'd’Mediathéik',
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Lassmaachen',
	'bouton_enlever_supprimer_document' => 'Läschen',
	'bouton_enlever_supprimer_document_confirmation' => 'Soll dëst Dokument wierklech geläscht ginn?',
	'bouton_modifier_document' => 'Änneren',
	'bouton_parcourir' => 'Driwwer kucken...',
	'bouton_refresh_document' => 'Dokument nei lueden',
	'bouton_remplacer_document' => 'Dokument ersetzen',
	'bouton_remplacer_image' => 'Bild ersetzen',
	'bouton_remplacer_image_document' => 'Duerch e Bild oder Dokument ersetzen',
	'bouton_supprimer' => 'Läschen',
	'bouton_supprimer_tous_orphelins' => 'All d’Weesekanner läschen', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Sollen déi @nb@ Weesekanner wierklech geläscht ginn?', # MODIF
	'bouton_upload' => 'Eroplueden',

	// D
	'des_audios' => '@nb@ Tounspuren',
	'des_documents' => '@nb@ Dokumenter',
	'des_files' => '@nb@ Dokumenter',
	'des_images' => '@nb@ Biller',
	'des_utilisations' => '@nb@ Uwennungen',
	'des_videos' => '@nb@ Sequenzen',
	'descriptif' => 'Beschreiwung',
	'document_attache_succes' => 'D’Dokument gouf bäigefléckt',
	'document_copie_locale_succes' => 'De Fichier gouf op de Site kopéiert',
	'document_installe_succes' => 'De Fichier gouf gelueden',
	'document_vu' => 'An den Text agesat',
	'documents' => 'Dokumenter',
	'documents_brises' => 'Futti',
	'documents_distants' => 'Distant',
	'documents_locaux' => 'Lokal',
	'documents_non_publies' => 'Net verëffentlecht',
	'documents_orphelins' => 'Net benotzt',
	'documents_publies' => 'Verëffentlecht',
	'documents_tous' => 'All',
	'double_clic_inserer_doc' => 'Duebel-Klick fir dës Ofkirzung an den Text ze iwerhuelen',

	// E
	'entree_dimensions' => 'Gréissten:',
	'entree_titre_document' => 'Titel vum Dokument:',
	'entree_titre_image' => 'Titel vum Bild:',
	'erreur_aucun_document' => 'Dëst Dokument existéiert net an der Mediathéik',
	'erreur_aucun_fichier' => 'Et gouf kee Fichier fonnt',
	'erreur_chemin_distant' => 'Den distante Fichier @nom@ gouf net fonnt',
	'erreur_chemin_ftp' => 'Dee Fichier gouf nët um Server fonnt',
	'erreur_copie_fichier' => 'Onméiglech de Fichier @nom@ déi richteg Plaz ze kopéieren',
	'erreur_dossier_tmp_manquant' => 'E provisoreschen Dossier fir d’Fichier’en eropzeluede feelt',
	'erreur_ecriture_fichier' => 'Fehler beim Schreiwe vum Fichier op den Disk',
	'erreur_format_fichier_image' => 'De Format vu @nom@ ass kee Bild-Format',
	'erreur_indiquez_un_fichier' => 'Wielt e Fichier aus!',
	'erreur_insertion_document_base' => 'Onméiglech d’Dokument @fichier@ an der Datebank ze späicheren',
	'erreur_suppression_vignette' => 'Fehler beim Läsche vun der Vignette',
	'erreur_upload_type_interdit' => 'D’Eropluede vu Fichier vum Typ @nom@ ass net erlaabt',
	'erreur_upload_vignette' => 'Fehler beim Eropluede vun der Vignette @nom@',
	'erreurs' => '@nb@ Fehler',
	'erreurs_voir' => '@nb@ Fehler weisen',

	// F
	'fichier_distant' => 'Distante Fichier',
	'fichier_manquant' => 'Fichier feelt',
	'fichier_modifie' => 'De Fichier gouf geännert. Klickt fir ze späicheren.',
	'format_date_incorrect' => 'Datum oder Zäit si falsch',

	// I
	'icone_creer_document' => 'Dokument bäiflécken',
	'id' => 'ID',
	'image_tourner_180' => '180° dréien',
	'image_tourner_droite' => '90° no riets dréien',
	'image_tourner_gauche' => '90° no lénks dréien',
	'info_doc_max_poids' => 'D’Maximalgréisst vun den Dokumenter ass @maxi@ (dëse Fichier huet @actuel@).',
	'info_document' => 'Dokument',
	'info_document_indisponible' => 'Dëst Dokument gëtt ët nët',
	'info_documents' => 'Dokumenter',
	'info_gauche_numero_document' => 'Dokument Nummer',
	'info_hauteur' => 'Héicht',
	'info_heure' => 'Zäit',
	'info_illustrations' => 'Illustratiounen',
	'info_image_max_poids' => 'D’Maximalgréisst vun de Biller ass @maxi@ (dëse Fichier huet @actuel@).',
	'info_image_max_taille' => 'D’Maximalgréisst vun de Biller ass @maxi@ (dëse Fichier huet @actuel@).',
	'info_inclusion_directe' => 'Direkt Abannung:',
	'info_inclusion_vignette' => 'Ubannen vun der Vignette:',
	'info_installer_tous_documents' => 'All d’Dokumenter eroplueden',
	'info_largeur' => 'Breet',
	'info_logo_max_taille' => 'D’Logoen mussen manner wéi @maxi@ hun (dëse Fichier huet @actuel@).',
	'info_modifier_document' => 'Dokument änneren',
	'info_portfolio' => 'Portefeuille',
	'info_referencer_doc_distant' => 'En Dokument vum Internet referenzéieren:',
	'info_sans_vignette' => 'Ouni Vignette',
	'info_statut_document' => 'Dëst Dokument ass:',
	'info_telecharger' => 'Vun ärem Computer eroplueden:',
	'infos' => 'Eng Info fir all d’Rubrike weisen (wann dir verschidden Informatioune wëllt, da benotzt d’Beschreiwung).',
	'item_autoriser_selectionner_date_en_ligne' => 'Erlaaben den Datum vun all Dokument ze änneren',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Den Datum vun den Dokumenter ass deen wéini së op de Site gesaat goufen',

	// L
	'label_activer_document_objets' => 'D’Eropluede vir dës Inhalter aschalten:',
	'label_apercu' => 'Iwwersiicht',
	'label_caracteristiques' => 'Charakteristik',
	'label_credits' => 'Krediter',
	'label_fichier' => 'Fichier',
	'label_fichier_vignette' => 'Vignette',
	'label_paginer_par' => 'Pro Säit:',
	'label_parents' => 'Dëst Dokument ass verlinkt mat',
	'label_refdoc_joindre' => 'Dokument Nummer',
	'lien_tout_enlever' => 'Alles ewech huelen', # MODIF
	'logo' => 'Logo',

	// M
	'media_audio' => 'Tounpisten',
	'media_file' => 'Anerer',
	'media_image' => 'Biller',
	'media_video' => 'Sequenzen',
	'miniature_automatique_active' => 'SPIP erstellt automatesch eng Miniatur vum Bild',

	// N
	'nb_documents_attache_succes' => '@nb@ Dokumenter goufe bäigefléckt',
	'nb_documents_installe_succes' => '@nb@ Fichier’en gelueden',

	// O
	'objet_document' => 'Dokument',
	'objet_documents' => 'Dokumenter',

	// P
	'par_date' => 'no Datum',
	'par_hauteur' => 'Héicht',
	'par_id' => 'ID',
	'par_largeur' => 'Breet',
	'par_taille' => 'Gewiicht',
	'par_titre' => 'No Titel',

	// T
	'texte_documents_joints' => 'Dir kënnt en Interface aschalten fir Dokumenter (Fichier’en, Biller, Multimedia, asw) bei Artikelen, Rubriken oder aner Elementer bäi ze setzen. Dës Fichier’en kënnen dann am Artikel verlinkt oder separat ugewisen ginn.',
	'texte_documents_joints_2' => 'Dës Astellung verhënnert net Biller oder Dokumenter direkt an den Text derbäi ze setzen.',
	'titre_documents_joints' => 'Gelinkten Dokumenter',
	'titre_page_documents_edit' => 'Dokument änneren: @titre@',
	'tous_les_medias' => 'All Medien',
	'tout_dossier_upload' => 'De ganzen Dossier @upload@',
	'tout_voir' => 'Alles weisen',

	// U
	'un_audio' => '1 Tounpist',
	'un_document' => '1 Dokument',
	'un_file' => '1 Dokument',
	'un_image' => '1 Bild',
	'un_video' => '1 Sequenz',
	'une_utilisation' => '1 mol benotzt',
	'upload_fichier_zip' => 'ZIP-Fichier',
	'upload_fichier_zip_texte' => 'De Fichier deen dër installéieren wëllt ass en Zip-Fichier.',
	'upload_fichier_zip_texte2' => 'Dëse Fichier ka sinn:',
	'upload_info_mode_document' => 'Dëst Bild an de Portefeuille setzen',
	'upload_info_mode_image' => 'Dëst Bild aus dem Portefeuille eraushuelen',
	'upload_limit' => 'Dëse Fichier ass ze grouss fir de Server; déi maximal Gréisst fir <i>eropzelueden</i> ass @max@.',
	'upload_zip_conserver' => 'Archiv no der Extraktioun halen',
	'upload_zip_decompacter' => 'de-kompriméiert an all Element um Site installéiert. D’Fichier’en déi dann um Site installéiert ginn sinn:',
	'upload_zip_mode_document' => 'All d’Biller an de Portefeuille setzen',
	'upload_zip_telquel' => 'esou wéi en ass, als kompriméierten Zip-Archiv installéiert;',
	'upload_zip_titrer' => 'Titel ginn baséiert um Numm vum Fichier',

	// V
	'verifier_documents_brises' => 'D’Fichier’en déi feele kontrolléieren',
	'verifier_documents_inutilises' => 'D’Linke vun den Dokumenter kontrolléieren',
	'vignette_supprimee' => 'D’Vignette gouf geläscht'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_audio' => 'Keng Tounspur',
	'aucun_document' => 'Keen Dokument',
	'aucun_file' => 'Kee Dokument',
	'aucun_image' => 'Kee Bild',
	'aucun_video' => 'Kéng Sequenz',
	'aucune_utilisation' => 'Dëst Dokument gëtt net benotzt',
	'aucune_vignette' => 'Keng Vignette',

	// B
	'bouton_ajouter_document' => 'Dokument derbäi setzen',
	'bouton_ajouter_image' => 'Bild derbäi setzen',
	'bouton_ajouter_image_document' => 'E Bild oder en Dokument derbäi setzen',
	'bouton_attacher_document' => 'Unhänken',
	'bouton_copier_local' => 'Op de Site kopéieren',
	'bouton_download_depuis' => 'zënter:',
	'bouton_download_local' => 'mäi Computer',
	'bouton_download_par_ftp' => 'de Server',
	'bouton_download_par_mediatheque' => 'd’Mediathéik',
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Lassmaachen',
	'bouton_enlever_supprimer_document' => 'Läschen',
	'bouton_enlever_supprimer_document_confirmation' => 'Soll dëst Dokument wierklech geläscht ginn?',
	'bouton_modifier_document' => 'Änneren',
	'bouton_parcourir' => 'Driwwer kucken...',
	'bouton_refresh_document' => 'Dokument nei lueden',
	'bouton_remplacer_document' => 'Dokument ersetzen',
	'bouton_remplacer_image' => 'Bild ersetzen',
	'bouton_remplacer_image_document' => 'Duerch e Bild oder Dokument ersetzen',
	'bouton_supprimer' => 'Läschen',
	'bouton_supprimer_tous_orphelins' => 'All d’Weesekanner läschen', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Sollen déi @nb@ Weesekanner wierklech geläscht ginn?', # MODIF
	'bouton_upload' => 'Eroplueden',

	// D
	'des_audios' => '@nb@ Tounspuren',
	'des_documents' => '@nb@ Dokumenter',
	'des_files' => '@nb@ Dokumenter',
	'des_images' => '@nb@ Biller',
	'des_utilisations' => '@nb@ Uwennungen',
	'des_videos' => '@nb@ Sequenzen',
	'descriptif' => 'Beschreiwung', # MODIF
	'document_attache_succes' => 'D’Dokument gouf bäigefléckt',
	'document_copie_locale_succes' => 'De Fichier gouf op de Site kopéiert',
	'document_installe_succes' => 'De Fichier gouf gelueden',
	'document_vu' => 'An den Text agesat',
	'documents' => 'Dokumenter',
	'documents_brises' => 'Futti',
	'documents_distants' => 'Distant',
	'documents_locaux' => 'Lokal',
	'documents_non_publies' => 'Net verëffentlecht',
	'documents_orphelins' => 'Net benotzt',
	'documents_publies' => 'Verëffentlecht',
	'documents_tous' => 'All',
	'double_clic_inserer_doc' => 'Duebel-Klick fir dës Ofkirzung an den Text ze iwerhuelen',

	// E
	'entree_dimensions' => 'Gréissten:',
	'entree_titre_document' => 'Titel vum Dokument:',
	'entree_titre_image' => 'Titel vum Bild:',
	'erreur_aucun_document' => 'Dëst Dokument existéiert net an der Mediathéik',
	'erreur_aucun_fichier' => 'Et gouf kee Fichier fonnt',
	'erreur_chemin_distant' => 'Den distante Fichier @nom@ gouf net fonnt',
	'erreur_chemin_ftp' => 'Dee Fichier gouf nët um Server fonnt',
	'erreur_copie_fichier' => 'Onméiglech de Fichier @nom@ déi richteg Plaz ze kopéieren',
	'erreur_dossier_tmp_manquant' => 'E provisoreschen Dossier fir d’Fichier’en eropzeluede feelt',
	'erreur_ecriture_fichier' => 'Fehler beim Schreiwe vum Fichier op den Disk',
	'erreur_format_fichier_image' => 'De Format vu @nom@ ass kee Bild-Format',
	'erreur_indiquez_un_fichier' => 'Wielt e Fichier aus!',
	'erreur_insertion_document_base' => 'Onméiglech d’Dokument @fichier@ an der Datebank ze späicheren',
	'erreur_suppression_vignette' => 'Fehler beim Läsche vun der Vignette',
	'erreur_upload_type_interdit' => 'D’Eropluede vu Fichier vum Typ @nom@ ass net erlaabt',
	'erreur_upload_vignette' => 'Fehler beim Eropluede vun der Vignette @nom@',
	'erreurs' => '@nb@ Fehler',
	'erreurs_voir' => '@nb@ Fehler weisen',

	// F
	'fichier_distant' => 'Distante Fichier',
	'fichier_manquant' => 'Fichier feelt',
	'fichier_modifie' => 'De Fichier gouf geännert. Klickt fir ze späicheren.',
	'format_date_incorrect' => 'Datum oder Zäit si falsch',

	// I
	'icone_creer_document' => 'Dokument bäiflécken',
	'id' => 'ID',
	'image_tourner_180' => '180° dréien',
	'image_tourner_droite' => '90° no riets dréien',
	'image_tourner_gauche' => '90° no lénks dréien',
	'info_doc_max_poids' => 'D’Maximalgréisst vun den Dokumenter ass @maxi@ (dëse Fichier huet @actuel@).',
	'info_document' => 'Dokument',
	'info_document_indisponible' => 'Dëst Dokument gëtt ët nët',
	'info_documents' => 'Dokumenter',
	'info_gauche_numero_document' => 'Dokument Nummer',
	'info_hauteur' => 'Héicht',
	'info_heure' => 'Zäit',
	'info_illustrations' => 'Illustratiounen',
	'info_image_max_poids' => 'D’Maximalgréisst vun de Biller ass @maxi@ (dëse Fichier huet @actuel@).',
	'info_image_max_taille' => 'D’Maximalgréisst vun de Biller ass @maxi@ (dëse Fichier huet @actuel@).',
	'info_inclusion_directe' => 'Direkt Abannung:',
	'info_inclusion_vignette' => 'Ubannen vun der Vignette:',
	'info_installer_tous_documents' => 'All d’Dokumenter eroplueden',
	'info_largeur' => 'Breet',
	'info_logo_max_taille' => 'D’Logoen mussen manner wéi @maxi@ hun (dëse Fichier huet @actuel@).',
	'info_modifier_document' => 'Dokument änneren',
	'info_portfolio' => 'Portefeuille',
	'info_referencer_doc_distant' => 'En Dokument vum Internet referenzéieren:',
	'info_sans_vignette' => 'Ouni Vignette',
	'info_statut_document' => 'Dëst Dokument ass:',
	'info_telecharger' => 'Vun ärem Computer eroplueden:',
	'infos' => 'Eng Info fir all d’Rubrike weisen (wann dir verschidden Informatioune wëllt, da benotzt d’Beschreiwung).',
	'item_autoriser_selectionner_date_en_ligne' => 'Erlaaben den Datum vun all Dokument ze änneren',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Den Datum vun den Dokumenter ass deen wéini së op de Site gesaat goufen',

	// L
	'label_activer_document_objets' => 'D’Eropluede vir dës Inhalter aschalten:',
	'label_apercu' => 'Iwwersiicht',
	'label_caracteristiques' => 'Charakteristik',
	'label_credits' => 'Krediter',
	'label_fichier' => 'Fichier',
	'label_fichier_vignette' => 'Vignette',
	'label_paginer_par' => 'Pro Säit:',
	'label_parents' => 'Dëst Dokument ass verlinkt mat',
	'label_refdoc_joindre' => 'Dokument Nummer',
	'lien_tout_enlever' => 'Alles ewech huelen', # MODIF
	'logo' => 'Logo',

	// M
	'media_audio' => 'Tounpisten',
	'media_file' => 'Anerer',
	'media_image' => 'Biller',
	'media_video' => 'Sequenzen',
	'miniature_automatique_active' => 'SPIP erstellt automatesch eng Miniatur vum Bild',

	// N
	'nb_documents_attache_succes' => '@nb@ Dokumenter goufe bäigefléckt',
	'nb_documents_installe_succes' => '@nb@ Fichier’en gelueden',

	// O
	'objet_document' => 'Dokument',
	'objet_documents' => 'Dokumenter',

	// P
	'par_date' => 'no Datum',
	'par_hauteur' => 'Héicht',
	'par_id' => 'ID',
	'par_largeur' => 'Breet',
	'par_taille' => 'Gewiicht',
	'par_titre' => 'No Titel',

	// T
	'texte_documents_joints' => 'Dir kënnt en Interface aschalten fir Dokumenter (Fichier’en, Biller, Multimedia, asw) bei Artikelen, Rubriken oder aner Elementer bäi ze setzen. Dës Fichier’en kënnen dann am Artikel verlinkt oder separat ugewisen ginn.',
	'texte_documents_joints_2' => 'Dës Astellung verhënnert net Biller oder Dokumenter direkt an den Text derbäi ze setzen.',
	'titre_documents_joints' => 'Gelinkten Dokumenter',
	'titre_page_documents_edit' => 'Dokument änneren: @titre@',
	'tous_les_medias' => 'All Medien',
	'tout_dossier_upload' => 'De ganzen Dossier @upload@',
	'tout_voir' => 'Alles weisen',

	// U
	'un_audio' => '1 Tounpist',
	'un_document' => '1 Dokument',
	'un_file' => '1 Dokument',
	'un_image' => '1 Bild',
	'un_video' => '1 Sequenz',
	'une_utilisation' => '1 mol benotzt',
	'upload_fichier_zip' => 'ZIP-Fichier',
	'upload_fichier_zip_texte' => 'De Fichier deen dër installéieren wëllt ass en Zip-Fichier.',
	'upload_fichier_zip_texte2' => 'Dëse Fichier ka sinn:',
	'upload_info_mode_document' => 'Dëst Bild an de Portefeuille setzen',
	'upload_info_mode_image' => 'Dëst Bild aus dem Portefeuille eraushuelen',
	'upload_limit' => 'Dëse Fichier ass ze grouss fir de Server; déi maximal Gréisst fir <i>eropzelueden</i> ass @max@.',
	'upload_zip_conserver' => 'Archiv no der Extraktioun halen',
	'upload_zip_decompacter' => 'de-kompriméiert an all Element um Site installéiert. D’Fichier’en déi dann um Site installéiert ginn sinn:',
	'upload_zip_mode_document' => 'All d’Biller an de Portefeuille setzen',
	'upload_zip_telquel' => 'esou wéi en ass, als kompriméierten Zip-Archiv installéiert;',
	'upload_zip_titrer' => 'Titel ginn baséiert um Numm vum Fichier',

	// V
	'verifier_documents_brises' => 'D’Fichier’en déi feele kontrolléieren',
	'verifier_documents_inutilises' => 'D’Linke vun den Dokumenter kontrolléieren',
	'vignette_supprimee' => 'D’Vignette gouf geläscht',
];
